==> axios-token-manager-0.2.2.tgz: package/lib/esm/tokenManager.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import Semaphore from 'semaphore-async-await';
import { defaultSettings } from './utils/initialValues';
import { getFreshToken } from './utils/getFreshToken';
import { isTokenValid } from './utils/isTokenValid';
import { shouldRecover } from './utils/shouldRecover';
import { getToken } from './utils/getToken';
import { updateState, getState, setInitialState } from './state';
var lock = new Semaphore(1);
var _instance;
var requestInterceptor = function (config) { return __awaiter(void 0, void 0, void 0, function () {
    var options, token, access_token, header, formatter;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                options = getState().options;
                return [4 /*yield*/, getToken(lock)];
            case 1:
                token = _a.sent();
                access_token = token.access_token;
                header = options.header, formatter = options.formatter;
                config.headers[header] = formatter(access_token);
                return [2 /*return*/, config];
        }
    });
}); };
var successInterceptor = function (response) {
    var inRecovery = getState().inRecovery;
    if (inRecovery) {
        updateState({
            recoveryTries: 0,
            inRecovery: false
        });
    }
    return response;
};
var errorInterceptor = function (error) { return __awaiter(void 0, void 0, void 0, function () {
    var needsToRecover, _a, cache, getCredentials, error_1, options, response, config, token, access_token, header, formatter, onRecoveryTry, addTokenToLogs, message;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                needsToRecover = shouldRecover(error);
                if (!needsToRecover) return [3 /*break*/, 7];
                return [4 /*yield*/, lock.acquire()];
            case 1:
                _b.sent();
                _a = getState(), cache = _a.cache, getCredentials = _a.getCredentials;
                if (!isTokenValid(cache)) return [3 /*break*/, 2];
                lock.release();
                return [3 /*break*/, 6];
            case 2:
                _b.trys.push([2, 4, 5, 6]);
                return [4 /*yield*/, getFreshToken(getCredentials)];
            case 3:
                _b.sent();
                return [3 /*break*/, 6];
            case 4:
                error_1 = _b.sent();
                return [2 /*return*/, Promise.reject(error_1)];
            case 5:
                lock.release();
                return [7 /*endfinally*/];
            case 6:
                options = getState().options;
                response = error.response;
                config = response.config;
                token = cache.token;
                access_token = token.access_token;
                header = options.header, formatter = options.formatter, onRecoveryTry = options.onRecoveryTry, addTokenToLogs = options.addTokenToLogs;
                config.headers[header] = formatter(access_token);
                message = addTokenToLogs ? "Using token: ".concat(access_token, ".") : '';
                onRecoveryTry(message);
                return [2 /*return*/, _instance(config)];
            case 7: return [2 /*return*/, Promise.reject(error)];
        }
    });
}); };
var tokenManager = function (settings) {
    var instance = settings.instance, getCredentials = settings.getCredentials, rest = __rest(settings, ["instance", "getCredentials"]);
    _instance = instance;
    var options = __assign(__assign({}, defaultSettings), rest);
    setInitialState(options, getCredentials);
    instance.interceptors.request.use(requestInterceptor);
    instance.interceptors.response.use(successInterceptor, errorInterceptor);
};
export default tokenManager;

==> axios-token-manager-0.2.3.tgz: package/lib/esm/tokenManager.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import Semaphore from 'semaphore-async-await';
import { defaultSettings } from './utils/initialValues';
import { getFreshToken } from './utils/getFreshToken';
import { isTokenValid } from './utils/isTokenValid';
import { shouldRecover } from './utils/shouldRecover';
import { getToken } from './utils/getToken';
import { updateState, getState, setInitialState } from './state';
var lock = new Semaphore(1);
var _instance;
var requestInterceptor = function (config) { return __awaiter(void 0, void 0, void 0, function () {
    var options, token, access_token, header, formatter;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                options = getState().options;
                return [4 /*yield*/, getToken(lock)];
            case 1:
                token = _a.sent();
                access_token = token.access_token;
                header = options.header, formatter = options.formatter;
                config.headers[header] = formatter(access_token);
                return [2 /*return*/, config];
        }
    });
}); };
var successInterceptor = function (response) {
    var inRecovery = getState().inRecovery;
    if (inRecovery) {
        updateState({
            recoveryTries: 0,
            inRecovery: false
        });
    }
    return response;
};
var errorInterceptor = function (error) { return __awaiter(void 0, void 0, void 0, function () {
    var needsToRecover, token, _a, cache, getCredentials, error_1, options, response, config, access_token, header, formatter, onRecoveryTry, addTokenToLogs, message;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                needsToRecover = shouldRecover(error);
                if (!needsToRecover) return [3 /*break*/, 7];
                token = void 0;
                return [4 /*yield*/, lock.acquire()];
            case 1:
                _b.sent();
                _a = getState(), cache = _a.cache, getCredentials = _a.getCredentials;
                if (!isTokenValid(cache)) return [3 /*break*/, 2];
                token = cache.token;
                lock.release();
                return [3 /*break*/, 6];
            case 2:
                _b.trys.push([2, 4, 5, 6]);
                return [4 /*yield*/, getFreshToken(getCredentials)];
            case 3:
                token = _b.sent();
                return [3 /*break*/, 6];
            case 4:
                error_1 = _b.sent();
                return [2 /*return*/, Promise.reject(error_1)];
            case 5:
                lock.release();
                return [7 /*endfinally*/];
            case 6:
                options = getState().options;
                response = error.response;
                config = response.config;
                access_token = token.access_token;
                header = options.header, formatter = options.formatter, onRecoveryTry = options.onRecoveryTry, addTokenToLogs = options.addTokenToLogs;
                (config.headers)[header] = formatter(access_token);
                message = addTokenToLogs ? "Using token: ".concat(access_token, ".") : '';
                onRecoveryTry(message);
                return [2 /*return*/, _instance(config)];
            case 7: return [2 /*return*/, Promise.reject(error)];
        }
    });
}); };
var tokenManager = function (settings) {
    var instance = settings.instance, getCredentials = settings.getCredentials, rest = __rest(settings, ["instance", "getCredentials"]);
    _instance = instance;
    var options = __assign(__assign({}, defaultSettings), rest);
    setInitialState(options, getCredentials);
    instance.interceptors.request.use(requestInterceptor);
    instance.interceptors.response.use(successInterceptor, errorInterceptor);
};
export default tokenManager;
